@@ -6,10 +6,9 @@ from enum import Enum
 from typing import Any, Dict, List, Optional, Tuple, Union
 
 from bson.objectid import ObjectId
-from pydantic import UUID4, BaseModel, Field
-
 from msaDocModels import wdc
 from msaDocModels.utils.htmlutils import sanitize
+from pydantic import UUID4, BaseModel, Field
 
 
 def get_crlf() -> str:
@@ -410,9 +409,7 @@ class SDUPage(BaseModel):
                 ret += txt + get_crlf()
             else:
                 txt = par.get_text()
-                if par.semantic_type.__contains__(
-                    "head"
-                ) or par.semantic_type.__contains__("title"):
+                if par.semantic_type.__contains__("head") or par.semantic_type.__contains__("title"):
                     ret += get_crlf() + txt + get_crlf()
                 elif len(par.sentences) > 1:
                     ret += txt + get_cr_paragraph()
@@ -954,9 +951,7 @@ class SPKTaxonomyCompaniesDTO(BaseModel):
     companies_winner: Optional[SPKCompany]
 
 
-class SPKTaxonomyDTO(
-    SPKTaxonomyCountriesDTO, SPKTaxonomyCompaniesDTO, SPKTaxonomyCitiesDTO
-):
+class SPKTaxonomyDTO(SPKTaxonomyCountriesDTO, SPKTaxonomyCompaniesDTO, SPKTaxonomyCitiesDTO):
     """DTO, representing the result of service Taxonomy."""
 
 
@@ -1428,3 +1423,259 @@ class FieldName(str, Enum):
     LearnsetDataInput = "learnset"
     ModelDataInput = "model"
     TaxonomyDataInput = "taxonomy"
+
+
+class ExtractionDefaultResult(BaseModel):
+    """
+    Model for representing an extracted entity.
+
+    Attributes:
+        text: The text of the extracted entity.
+        start: The start index of the extracted entity in the input text.
+        end: The end index of the extracted entity in the input text.
+    """
+
+    text: str
+    start: int
+    end: int
+
+
+class RecognizerDefaultResult(ExtractionDefaultResult):
+    """
+    Model for representing a recognized entity.
+
+    Attributes:
+        type: The type of the recognized entity.
+    """
+
+    type: str
+
+
+class SPKEntityExtractorInput(TextInput):
+    """Model that contains input data for extract defaults."""
+    language: SDULanguage = SDULanguage(code="de", lang="german")
+
+
+class SPKEntityExtractorDocumentInput(DocumentLangInput):
+    """
+    Model that contains input data for extract defaults.
+
+    Attributes:
+        pages_text: The document data.
+        language: language.
+
+    """
+    pages_text: List[SDUPage] = []
+    language: SDULanguage = SDULanguage(code="de", lang="german")
+
+
+class SPKEntityExtractorDocumentDTO(BaseModel):
+    """
+    Model that contains extraction data implemented in page data.
+
+    Attributes:
+        pages_text: The document data with extractions with the same structure.
+
+    """
+    pages_text: List[SDUPage] = []
+
+
+class SPKTextExtractionDefaults(BaseModel):
+    """
+    Data transfer object for SPK entity extractor.
+
+    Attributes:
+        recognizer: List of recognizer results.
+        zipcode: List of extracted zipcodes.
+        phone_number: List of extracted phone numbers.
+        url: List of extracted URLs.
+        credit_card: List of extracted credit card numbers.
+        credit_cards_strict: List of strictly extracted credit card numbers.
+        ipv4: List of extracted IPv4 addresses.
+        ipv6: List of extracted IPv6 addresses.
+        mac_address: List of extracted MAC addresses.
+        hex_value: List of extracted hexadecimal values.
+        slug: List of extracted slugs.
+        bitcoin_address: List of extracted Bitcoin addresses.
+        yandex_money_address: List of extracted Yandex Money addresses.
+        latitude: List of extracted latitudes.
+        longitude:  List of extracted longitudes.
+        irc :  list  IRCs
+        license_plate : list License plates
+        time : list Time
+        iso_datetime : list ISO datetime
+        isbn : list ISBNs
+        roman_numeral : list Roman numerals
+        ethereum_address : list Ethereum addresses
+        ethereum_hash : list Ethereum hashes
+        uuid : list UUIDs
+        float_number : list Float numbers
+        pgp_fingerprint : list PGP fingerprints
+        pesel :list PESELs
+    """
+
+    recognizer: List[RecognizerDefaultResult]
+    zipcode: List[ExtractionDefaultResult]
+    phone_number: List[ExtractionDefaultResult]
+    url: List[ExtractionDefaultResult]
+    credit_card: List[ExtractionDefaultResult]
+    credit_cards_strict: List[ExtractionDefaultResult]
+    ipv4: List[ExtractionDefaultResult]
+    ipv6: List[ExtractionDefaultResult]
+    mac_address: List[ExtractionDefaultResult]
+    hex_value: List[ExtractionDefaultResult]
+    slug: List[ExtractionDefaultResult]
+    bitcoin_address: List[ExtractionDefaultResult]
+    yandex_money_address: List[ExtractionDefaultResult]
+    latitude: List[ExtractionDefaultResult]
+    longitude: List[ExtractionDefaultResult]
+    irc: List[ExtractionDefaultResult]
+    license_plate: List[ExtractionDefaultResult]
+    time: List[ExtractionDefaultResult]
+    iso_datetime: List[ExtractionDefaultResult]
+    isbn: List[ExtractionDefaultResult]
+    roman_numeral: List[ExtractionDefaultResult]
+    ethereum_address: List[ExtractionDefaultResult]
+    ethereum_hash: List[ExtractionDefaultResult]
+    uuid: List[ExtractionDefaultResult]
+    float_number: List[ExtractionDefaultResult]
+    pgp_fingerprint: List[ExtractionDefaultResult]
+    pesel: List[ExtractionDefaultResult]
+
+
+class SPKTextExtractionDefaultsDTO(BaseModel):
+    """DTO, representing the result of extraction defaults"""
+
+    extractions: Union[
+        SPKTextExtractionDefaults, List[SPKTextExtractionDefaults], Dict[Any, SPKTextExtractionDefaults]
+    ]
+
+
+class SPKTextExtractionNLPInput(DocumentLangInput):
+    """
+    Data input model for extraction NLP from text.
+
+    Attributes:
+
+        entities: Use this processor, recognizes mention spans of a particular entity type.
+        sentiment: Use this processor, pre-trained word vectors for sentence-level classification tasks.
+        dependencies: Use this processor, builds a tree structure of words.
+    """
+
+    entities: bool = True
+    sentiment: bool = False
+    dependencies: bool = True
+
+
+class SPKTextExtractionDocumentNLPInput(DocumentLangInput):
+    """
+    Data input model for extraction NLP from document.
+
+    Attributes:
+
+        pages_text: The document data.
+        language: language.
+        entities: Use this processor, recognizes mention spans of a particular entity type.
+        sentiment: Use this processor, pre-trained word vectors for sentence-level classification tasks.
+        dependencies: Use this processor, builds a tree structure of words.
+    """
+    pages_text: List[SDUPage] = []
+    language: SDULanguage = SDULanguage(code="de", lang="german")
+    entities: bool = True
+    sentiment: bool = False
+    dependencies: bool = True
+
+
+class SPKTextExtractionDocumentNLPDTO(BaseModel):
+    """
+    Model that contains extraction data implemented in page data.
+
+    Attributes:
+        document_data: The document data with extractions with the same structure.
+
+    """
+    document_data: List[SDUPage] = []
+
+
+class SPKExtractionNLP(BaseModel):
+    """
+    Model which represent find NLP in text.
+
+    Attributes:
+
+        id: id of founded entity.
+        text: found entity
+        upos: upos in text.
+        xpos: xpos in text.
+        feats: features of entity.
+        start: start char in text.
+        end: end char in text.
+    """
+
+    id: int
+    text: str
+    upos: str
+    xpos: str
+    feats: Optional[str]
+    start: int
+    end: int
+
+
+class SPKTextExtractionNLPDTO(BaseModel):
+    """
+    Data input model for Text Clean.
+
+    Attributes:
+
+        extractions: List of SPKExtractionNLP.
+    """
+
+    extractions: Union[List[SPKExtractionNLP], List[List[SPKExtractionNLP]], Dict[Any, List[List[SPKExtractionNLP]]]]
+
+
+class SPKTextExtractionInstallLanguage(BaseModel):
+    """
+    Install stanza module for transfer language.
+
+    Attributes:
+
+        language: SDULanguage object for this text.
+    """
+
+    language: SDULanguage = SDULanguage()
+
+
+class SPKTextExtractionInstallLanguageDTO(BaseModel):
+    """
+    Message of progress install language.
+
+    Attributes:
+
+        install: Message of progress install language.
+    """
+
+    install: str
+
+
+class SPKTextExtractionCapabilitiesInput(BaseModel):
+    """
+    Model to get Capabilities by language.
+
+    Attributes:
+
+        language: SDULanguage object for this text.
+    """
+
+    language: SDULanguage = SDULanguage()
+
+
+class SPKTextExtractionCapabilitiesDTO(BaseModel):
+    """
+    Represent Capabilities by language.
+
+    Attributes:
+
+        capabilities: Capabilities by language
+    """
+
+    capabilities: Any
